@@ -26,6 +26,12 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "Spring Regular Season" in name
         or "Round of" in name
         or "Second Round" in name
+        or "2015-2016 Barclays Premier League" in name
+        or "2014-2015 Barclays Premier League" in name
+        or "2013-2014 Barclays Premier League" in name
+        or "2012-2013 Barclays Premier League" in name
+        or "2011-2012 Barclays Premier League" in name
+        or "2010-2011 Barclays Premier League" in name
     ):
         return SeasonType.REGULAR
     if name == "Preseason" or "Spring Training" in name:
@@ -37,6 +43,10 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "3rd-Place" in name
         or "Final" in name
         or "Third Place" in name
+        or "Quarter-finals" in name
+        or "Semi-finals" in name
+        or "Play-In Season" in name
+        or "Spring Postseason" in name
     ):
         return SeasonType.POSTSEASON
     if name == "Off Season":
