@@ -3,7 +3,7 @@
 import datetime
 from typing import Any
 
-import requests_cache
+from scrapesession.scrapesession import ScrapeSession  # type: ignore
 
 from ...cache import MEMORY
 from ..google.google_address_model import create_google_address_model
@@ -13,7 +13,7 @@ from ..venue_model import VenueModel
 @MEMORY.cache(ignore=["session"])
 def create_espn_venue_model(
     venue: dict[str, Any],
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime,
     version: str,
 ) -> VenueModel:
@@ -26,11 +26,18 @@ def create_espn_venue_model(
         city = venue_address.get("city", "")
         state = venue_address.get("state", "")
         zipcode = venue_address.get("zipCode", "")
+        query = " - ".join([x for x in [name, city, state, zipcode] if x])
+        if not query:
+            query = venue_address["summary"]
         address = create_google_address_model(
-            " - ".join([x for x in [name, city, state, zipcode] if x]),
+            query,
             session,
             dt,
         )
+        if identifier is None:
+            identifier = query
+        if name is None:
+            name = query
     else:
         address = create_google_address_model(
             name,
