@@ -4,7 +4,7 @@
 import datetime
 
 import pytest_is_running
-import requests_cache
+from scrapesession.scrapesession import ScrapeSession  # type: ignore
 
 from ...cache import MEMORY
 from ..google.google_address_model import create_google_address_model
@@ -13,7 +13,7 @@ from ..venue_model import VERSION, VenueModel
 
 def _create_sportsreference_venue_model(
     venue_name: str | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime | None,
     version: str,
 ) -> VenueModel | None:
@@ -35,7 +35,7 @@ def _create_sportsreference_venue_model(
 @MEMORY.cache(ignore=["session"])
 def _cached_create_sportsreference_venue_model(
     venue_name: str | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime | None,
     version: str,
 ) -> VenueModel | None:
@@ -46,7 +46,7 @@ def _cached_create_sportsreference_venue_model(
 
 def create_sportsreference_venue_model(
     venue_name: str | None,
-    session: requests_cache.CachedSession,
+    session: ScrapeSession,
     dt: datetime.datetime | None,
 ) -> VenueModel | None:
     """Create a sports reference venue model."""
