@@ -10,6 +10,7 @@ from scrapesession.scrapesession import ScrapeSession  # type: ignore
 from scrapesession.scrapesession import create_scrape_session
 
 from .data.afl import AFLLeagueModel
+from .data.aflw import AFLWLeagueModel
 from .data.atp import ATPLeagueModel
 from .data.epl import EPLLeagueModel
 from .data.fifa import FIFALeagueModel
@@ -24,6 +25,7 @@ from .data.ncaaf import NCAAFLeagueModel
 from .data.nfl import NFLLeagueModel
 from .data.nhl import NHLLeagueModel
 from .data.wnba import WNBALeagueModel
+from .data.wta import WTALeagueModel
 
 
 class SportsBall:
@@ -76,6 +78,10 @@ class SportsBall:
                 self._leagues[league] = ATPLeagueModel(self._session, league_filter)
             elif league == League.WNBA:
                 self._leagues[league] = WNBALeagueModel(self._session, league_filter)
+            elif league == League.AFLW:
+                self._leagues[league] = AFLWLeagueModel(self._session, league_filter)
+            elif league == League.WTA:
+                self._leagues[league] = WTALeagueModel(self._session, league_filter)
             else:
                 raise ValueError(f"Unrecognised league: {league}")
         return self._leagues[league]
